@@ -25,8 +25,10 @@
    */
   angular
     .module('horizon.dashboard.developer', [
-      'horizon.dashboard.developer.theme-preview',
-      'horizon.dashboard.developer.resource-browser'
+      'horizon.dashboard.developer.form-builder',
+      'horizon.dashboard.developer.profiler',
+      'horizon.dashboard.developer.resource-browser',
+      'horizon.dashboard.developer.theme-preview'
     ])
     .config(config);
 
@@ -40,7 +42,7 @@
    * @description Base path for the developer dashboard
    */
   function config($provide, $windowProvider) {
-      var path = $windowProvider.$get().STATIC_URL + 'dashboard/developer/';
-      $provide.constant('horizon.dashboard.developer.basePath', path);
+    var path = $windowProvider.$get().STATIC_URL + 'dashboard/developer/';
+    $provide.constant('horizon.dashboard.developer.basePath', path);
   }
 })();
