@@ -72,21 +72,21 @@ class AdminProvidersTable(tables.DataTable):
     name = tables.WrappingColumn("name",
                                  verbose_name=_("Resource Provider Name"))
     vcpus_used = tables.Column("vcpus_used",
-                               verbose_name=_("VCPUs used"))
+                               verbose_name=_("vCPUs used"))
     vcpus_reserved = tables.Column("vcpus_reserved",
-                                   verbose_name=_("VCPUs reserved"))
+                                   verbose_name=_("vCPUs reserved"))
     vcpus = tables.Column("vcpus",
-                          verbose_name=_("VCPUs total"))
+                          verbose_name=_("vCPUs total"))
     vcpus_ar = tables.Column("vcpus_ar",
-                             verbose_name=_("VCPUs allocation ratio"))
+                             verbose_name=_("vCPUs allocation ratio"))
     pcpus_used = tables.Column("pcpus_used",
-                               verbose_name=_("PCPUs used"))
+                               verbose_name=_("pCPUs used"))
     pcpus_reserved = tables.Column("pcpus_reserved",
-                                   verbose_name=_("PCPUs reserved"))
+                                   verbose_name=_("pCPUs reserved"))
     pcpus = tables.Column("pcpus",
-                          verbose_name=_("PCPUs total"))
+                          verbose_name=_("pCPUs total"))
     pcpus_ar = tables.Column("pcpus_ar",
-                             verbose_name=_("PCPUs allocation ratio"))
+                             verbose_name=_("pCPUs allocation ratio"))
     memory_used = tables.Column("memory_mb_used",
                                 verbose_name=_("RAM used"),
                                 attrs={'data-type': 'size'},
