@@ -29,35 +29,40 @@ INDEX_TEMPLATE = 'horizon/common/_data_table_view.html'
 
 
 class InstanceViewTest(test.BaseAdminViewTests):
+
+    def _mock_image_list_detailed_side_effect(self, *args, **kwargs):
+        images = self.images.list()
+        if 'filters' in kwargs:
+            return [[image for image in images if
+                     image.visibility == 'community']]
+        else:
+            return [[image for image in images if
+                     image.visibility != 'community']]
+
     @test.create_mocks({
-        api.nova: ['flavor_list', 'server_list_paged', 'extension_supported'],
+        api.nova: ['flavor_list', 'server_list_paged'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def test_index(self):
         servers = self.servers.list()
         # TODO(vmarkov) instances_img_ids should be in test_data
-        instances_img_ids = [instance.image.get('id') for instance in
-                             servers if isinstance(instance.image, dict)]
-        self.mock_extension_supported.return_value = True
         self.mock_tenant_list.return_value = [self.tenants.list(), False]
-        self.mock_image_list_detailed_by_ids.return_value = self.images.list()
+
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
         self.mock_flavor_list.return_value = self.flavors.list()
         self.mock_server_list_paged.return_value = [servers, False, False]
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
 
         res = self.client.get(INDEX_URL)
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         instances = res.context['table'].data
         self.assertCountEqual(instances, servers)
 
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())] * 4)
-        self.assertEqual(15, self.mock_extension_supported.call_count)
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(), instances_img_ids)
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         self.mock_server_list_paged.assert_called_once_with(
@@ -66,19 +71,16 @@ class InstanceViewTest(test.BaseAdminViewTests):
             search_opts=search_opts)
 
     @test.create_mocks({
-        api.nova: ['flavor_list', 'flavor_get', 'server_list_paged',
-                   'extension_supported'],
+        api.nova: ['flavor_list', 'flavor_get', 'server_list_paged'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def test_index_flavor_list_exception(self):
         servers = self.servers.list()
         flavors = self.flavors.list()
-        instances_img_ids = [instance.image.get('id') for instance in
-                             servers if hasattr(instance, 'image')]
         full_flavors = OrderedDict([(f.id, f) for f in flavors])
         self.mock_server_list_paged.return_value = [servers, False, False]
-        self.mock_extension_supported.return_value = True
         self.mock_flavor_list.side_effect = self.exceptions.nova
         self.mock_tenant_list.return_value = [self.tenants.list(), False]
 
@@ -86,8 +88,9 @@ class InstanceViewTest(test.BaseAdminViewTests):
             return full_flavors[id]
         self.mock_flavor_get.side_effect = _get_full_flavor
 
-        self.mock_image_list_detailed_by_ids.return_value = self.images.list()
-
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
         res = self.client.get(INDEX_URL)
 
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
@@ -99,63 +102,46 @@ class InstanceViewTest(test.BaseAdminViewTests):
             test.IsHttpRequest(),
             sort_dir='desc',
             search_opts=search_opts)
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())] * 4)
-        self.assertEqual(15, self.mock_extension_supported.call_count)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
         self.mock_flavor_get.assert_has_calls(
             [mock.call(test.IsHttpRequest(), s.flavor['id']) for s in servers])
         self.assertEqual(len(servers), self.mock_flavor_get.call_count)
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(), instances_img_ids)
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
 
     @test.create_mocks({
-        api.nova: ['flavor_list', 'flavor_get', 'server_list_paged',
-                   'extension_supported'],
+        api.nova: ['flavor_list', 'flavor_get', 'server_list_paged'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def test_index_flavor_get_exception(self):
         servers = self.servers.list()
-        instances_img_ids = [instance.image.get('id') for instance in
-                             servers if hasattr(instance, 'image')]
         # UUIDs generated using indexes are unlikely to match
         # any of existing flavor ids and are guaranteed to be deterministic.
         for i, server in enumerate(servers):
             server.flavor['id'] = str(uuid.UUID(int=i))
 
-        self.mock_image_list_detailed_by_ids.return_value = self.images.list()
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
         self.mock_flavor_list.return_value = self.flavors.list()
         self.mock_server_list_paged.return_value = [servers, False, False]
-        self.mock_extension_supported.return_value = True
         self.mock_tenant_list.return_value = [self.tenants.list(), False]
         self.mock_flavor_get.side_effect = self.exceptions.nova
 
         res = self.client.get(INDEX_URL)
         instances = res.context['table'].data
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
-        # Since error messages produced for each instance are identical,
-        # there will be only one error message for all instances
-        # (messages de-duplication).
-        self.assertMessageCount(res, error=1)
         self.assertCountEqual(instances, servers)
 
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(), instances_img_ids)
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         self.mock_server_list_paged.assert_called_once_with(
             test.IsHttpRequest(),
             sort_dir='desc',
             search_opts=search_opts)
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())] * 4)
-        self.assertEqual(15, self.mock_extension_supported.call_count)
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
         self.mock_flavor_get.assert_has_calls(
             [mock.call(test.IsHttpRequest(), s.flavor['id']) for s in servers])
@@ -164,13 +150,16 @@ class InstanceViewTest(test.BaseAdminViewTests):
     @test.create_mocks({
         api.nova: ['server_list_paged', 'flavor_list'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def test_index_server_list_exception(self):
         self.mock_server_list_paged.side_effect = self.exceptions.nova
         self.mock_flavor_list.return_value = self.flavors.list()
         self.mock_tenant_list.return_value = [self.tenants.list(), False]
-        self.mock_image_list_detailed_by_ids.return_value = self.images.list()
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
 
         res = self.client.get(INDEX_URL)
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
@@ -182,18 +171,15 @@ class InstanceViewTest(test.BaseAdminViewTests):
             sort_dir='desc',
             search_opts=search_opts)
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(), [])
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
 
-    @test.create_mocks({api.nova: ['server_get', 'flavor_get',
-                                   'extension_supported'],
+    @test.create_mocks({api.nova: ['server_get', 'flavor_get'],
                         api.network: ['servers_update_addresses'],
                         api.keystone: ['tenant_get']})
     def test_ajax_loading_instances(self):
         server = self.servers.first()
         self.mock_server_get.return_value = server
-        self.mock_extension_supported.return_value = True
         self.mock_flavor_get.return_value = self.flavors.first()
         self.mock_tenant_get.return_value = self.tenants.first()
         self.mock_servers_update_addresses.return_value = None
@@ -211,18 +197,13 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertContains(res, "server_1", 2, 200)
         self.assertContains(res, "10.0.0.1", 1, 200)
         self.assertContains(res, "RAM</th><td>512MB", 1, 200)
-        self.assertContains(res, "VCPUs</th><td>1", 1, 200)
+        self.assertContains(res, "vCPUs</th><td>1", 1, 200)
         self.assertContains(res, "Size</th><td>0 GB", 1, 200)
         self.assertContains(res, "Active", 1, 200)
         self.assertContains(res, "Running", 1, 200)
 
         self.mock_server_get.assert_called_once_with(
             test.IsHttpRequest(), server.id)
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())])
-        self.assertEqual(3, self.mock_extension_supported.call_count)
         self.mock_flavor_get.assert_called_once_with(
             test.IsHttpRequest(), server.flavor['id'])
         self.mock_tenant_get.assert_called_once_with(
@@ -231,44 +212,38 @@ class InstanceViewTest(test.BaseAdminViewTests):
             test.IsHttpRequest(), [server])
 
     @test.create_mocks({
-        api.nova: ['flavor_list', 'server_list_paged', 'extension_supported'],
+        api.nova: ['flavor_list', 'server_list_paged'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def test_index_options_before_migrate(self):
-        servers = self.servers.list()
-        instances_img_ids = [instance.image.get('id') for instance in
-                             servers if hasattr(instance, 'image')]
         self.mock_tenant_list.return_value = [self.tenants.list(), False]
-        self.mock_image_list_detailed_by_ids.return_value = self.images.list()
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
         self.mock_flavor_list.return_value = self.flavors.list()
         self.mock_server_list_paged.return_value = [
             self.servers.list(), False, False]
-        self.mock_extension_supported.return_value = True
         res = self.client.get(INDEX_URL)
         self.assertContains(res, "instances__migrate")
         self.assertNotContains(res, "instances__confirm")
         self.assertNotContains(res, "instances__revert")
 
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(), instances_img_ids)
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         self.mock_server_list_paged.assert_called_once_with(
             test.IsHttpRequest(),
             sort_dir='desc',
             search_opts=search_opts)
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())] * 4)
-        self.assertEqual(15, self.mock_extension_supported.call_count)
 
     @test.create_mocks({
-        api.nova: ['flavor_list', 'server_list_paged', 'extension_supported'],
+        api.nova: ['flavor_list', 'server_list_paged'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def test_index_options_after_migrate(self):
         servers = self.servers.list()
@@ -276,12 +251,11 @@ class InstanceViewTest(test.BaseAdminViewTests):
         server1.status = "VERIFY_RESIZE"
         server2 = servers[2]
         server2.status = "VERIFY_RESIZE"
-        instances_img_ids = [instance.image.get('id') for instance in
-                             servers if hasattr(instance, 'image')]
         self.mock_tenant_list.return_value = [self.tenants.list(), False]
-        self.mock_image_list_detailed_by_ids.return_value = self.images.list()
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
         self.mock_flavor_list.return_value = self.flavors.list()
-        self.mock_extension_supported.return_value = True
         self.mock_server_list_paged.return_value = [servers, False, False]
 
         res = self.client.get(INDEX_URL)
@@ -290,14 +264,8 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertNotContains(res, "instances__migrate")
 
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(), instances_img_ids)
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())] * 4)
-        self.assertEqual(15, self.mock_extension_supported.call_count)
         search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         self.mock_server_list_paged.assert_called_once_with(
             test.IsHttpRequest(),
@@ -490,10 +458,10 @@ class InstanceViewTest(test.BaseAdminViewTests):
     @test.create_mocks({
         api.nova: ['flavor_list',
                    'flavor_get',
-                   'server_list_paged',
-                   'extension_supported'],
+                   'server_list_paged'],
         api.keystone: ['tenant_list'],
-        api.glance: ['image_list_detailed_by_ids'],
+        api.glance: ['image_list_detailed'],
+        api.cinder: ['volume_list']
     })
     def _test_servers_paginate_do(self,
                                   marker,
@@ -502,16 +470,16 @@ class InstanceViewTest(test.BaseAdminViewTests):
                                   has_prev):
         flavors = self.flavors.list()
         tenants = self.tenants.list()
-        images = self.images.list()
         # UUID indices are unique and are guaranteed being deterministic.
         for i, server in enumerate(servers):
             server.flavor['id'] = str(uuid.UUID(int=i))
 
         self.mock_server_list_paged.return_value = [
             servers, has_more, has_prev]
-        self.mock_extension_supported.return_value = True
         self.mock_flavor_list.return_value = flavors
-        self.mock_image_list_detailed_by_ids.return_value = images
+        self.mock_image_list_detailed.side_effect =\
+            self._mock_image_list_detailed_side_effect
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
         self.mock_tenant_list.return_value = [tenants, False]
         self.mock_flavor_get.side_effect = self.exceptions.nova
 
@@ -523,15 +491,8 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         self.assertEqual(res.status_code, 200)
 
-        self.mock_extension_supported.assert_has_calls([
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('AdminActions', test.IsHttpRequest()),
-            mock.call('Shelve', test.IsHttpRequest())])
-        self.assertEqual(3, self.mock_extension_supported.call_count)
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
-        self.mock_image_list_detailed_by_ids.assert_called_once_with(
-            test.IsHttpRequest(),
-            [server.image.id for server in servers])
+        self.assertEqual(self.mock_image_list_detailed.call_count, 4)
         self.mock_flavor_list.assert_called_once_with(test.IsHttpRequest())
         search_opts = {'marker': marker, 'paginate': True, 'all_tenants': True}
         self.mock_server_list_paged.assert_called_once_with(
