@@ -196,8 +196,10 @@ class NetworkTests(test.BaseAdminViewTests):
         self.assert_mock_multiple_calls_with_same_arguments(
             self.mock_network_get, 1,
             mock.call(test.IsHttpRequest(), network.id))
-        self.mock_port_list.assert_called_once_with(test.IsHttpRequest(),
-                                                    network_id=network.id)
+        self.mock_port_list.assert_called_once_with(
+            test.IsHttpRequest(),
+            network_id=network.id,
+            project_id=network.tenant_id)
         self._check_is_extension_supported(
             {'network-ip-availability': 1,
              'mac-learning': 1,
@@ -1003,7 +1005,7 @@ class NetworkTests(test.BaseAdminViewTests):
         url = reverse('horizon:admin:networks:create')
         res = self.client.get(url)
         physical_network = res.context['form'].fields['physical_network']
-        self.assertEqual(type(physical_network), forms.CharField)
+        self.assertIsInstance(physical_network, forms.CharField)
 
         self.mock_tenant_list.assert_called_once_with(test.IsHttpRequest())
         self._check_is_extension_supported(
@@ -1027,7 +1029,7 @@ class NetworkTests(test.BaseAdminViewTests):
         url = reverse('horizon:admin:networks:create')
         res = self.client.get(url)
         physical_network = res.context['form'].fields['physical_network']
-        self.assertEqual(type(physical_network), forms.ThemableChoiceField)
+        self.assertIsInstance(physical_network, forms.ThemableChoiceField)
         self.assertListEqual(list(physical_network.choices),
                              [('default', 'default'), ('test', 'test')])
 
