@@ -16,7 +16,7 @@
 import logging
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -38,7 +38,7 @@ class AddAllowedAddressPairForm(forms.SelfHandlingForm):
     failure_url = 'horizon:project:networks:ports:detail'
 
     def clean(self):
-        cleaned_data = super(AddAllowedAddressPairForm, self).clean()
+        cleaned_data = super().clean()
         if '/' not in self.data['ip']:
             cleaned_data['ip'] = self.data['ip']
         return cleaned_data
