@@ -17,7 +17,7 @@ import logging
 
 from django.conf import settings
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 import netaddr
 
 from horizon import exceptions
@@ -44,7 +44,9 @@ class CreateNetworkInfoAction(workflows.Action):
         required=False,
         help_text=_("If checked, the network will be enabled."))
     shared = forms.BooleanField(label=_("Shared"), initial=False,
-                                required=False)
+                                required=False,
+                                help_text=_("Share the network between "
+                                            "projects"))
     with_subnet = forms.BooleanField(label=_("Create Subnet"),
                                      widget=forms.CheckboxInput(attrs={
                                          'class': 'switchable',
@@ -65,10 +67,14 @@ class CreateNetworkInfoAction(workflows.Action):
         help_text=_("Availability zones where the DHCP agents may be "
                     "scheduled. Leaving this unset is equivalent to "
                     "selecting all availability zones"))
+    mtu = forms.IntegerField(
+        label=_("MTU"), required=False, min_value=68,
+        help_text=_("Maximum Transmission Unit. "
+                    "Minimum is 68 bytes for the IPv4 subnet "
+                    "and 1280 bytes for the IPv6 subnet."))
 
     def __init__(self, request, *args, **kwargs):
-        super(CreateNetworkInfoAction, self).__init__(request,
-                                                      *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
         if not policy.check((("network", "create_network:shared"),), request):
             self.fields['shared'].widget = forms.HiddenInput()
         try:
@@ -95,7 +101,7 @@ class CreateNetworkInfoAction(workflows.Action):
 class CreateNetworkInfo(workflows.Step):
     action_class = CreateNetworkInfoAction
     contributes = ("net_name", "admin_state", "with_subnet", "shared",
-                   "az_hints")
+                   "az_hints", "mtu")
 
 
 class CreateSubnetInfoAction(workflows.Action):
@@ -125,9 +131,9 @@ class CreateSubnetInfoAction(workflows.Action):
             'data-source-subnetpool': _('Address pool')},
             data_attrs=('name', 'prefixes',
                         'ip_version',
-                        'min_prefixlen',
-                        'max_prefixlen',
-                        'default_prefixlen'),
+                        'minimum_prefix_length',
+                        'maximum_prefix_length',
+                        'default_prefix_length'),
             transform=lambda x: "%s (%s)" % (x.name, ", ".join(x.prefixes))
                                 if 'prefixes' in x else "%s" % (x.name)),
         required=False)
@@ -204,8 +210,7 @@ class CreateSubnetInfoAction(workflows.Action):
                       ' the "Subnet Details" tab.')
 
     def __init__(self, request, context, *args, **kwargs):
-        super(CreateSubnetInfoAction, self).__init__(request, context, *args,
-                                                     **kwargs)
+        super().__init__(request, context, *args, **kwargs)
         if not setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK',
                                              'enable_ipv6'):
             self.fields['ip_version'].widget = forms.HiddenInput()
@@ -322,7 +327,7 @@ class CreateSubnetInfoAction(workflows.Action):
         if not with_subnet:
             self._remove_fields_errors()
             return None
-        cleaned_data = super(CreateSubnetInfoAction, self).clean()
+        cleaned_data = super().clean()
         self._check_subnet_data(cleaned_data)
         return cleaned_data
 
@@ -380,8 +385,7 @@ class CreateSubnetDetailAction(workflows.Action):
         help_text = _('Specify additional attributes for the subnet.')
 
     def __init__(self, request, context, *args, **kwargs):
-        super(CreateSubnetDetailAction, self).__init__(request, context,
-                                                       *args, **kwargs)
+        super().__init__(request, context, *args, **kwargs)
         if not setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK',
                                              'enable_ipv6'):
             self.fields['ipv6_modes'].widget = forms.HiddenInput()
@@ -447,7 +451,7 @@ class CreateSubnetDetailAction(workflows.Action):
             self._convert_ip_address(route[1], "host_routes")
 
     def clean(self):
-        cleaned_data = super(CreateSubnetDetailAction, self).clean()
+        cleaned_data = super().clean()
         self._check_allocation_pools(cleaned_data.get('allocation_pools'))
         self._check_host_routes(cleaned_data.get('host_routes'))
         self._check_dns_nameservers(cleaned_data.get('dns_nameservers'))
@@ -488,6 +492,8 @@ class CreateNetwork(workflows.Workflow):
                       'shared': data['shared']}
             if 'az_hints' in data and data['az_hints']:
                 params['availability_zone_hints'] = data['az_hints']
+            if data['mtu']:
+                params['mtu'] = data['mtu']
             network = api.neutron.network_create(request, **params)
             self.context['net_id'] = network.id
             LOG.debug('Network "%s" was successfully created.',
@@ -608,6 +614,6 @@ class CreateNetwork(workflows.Workflow):
                                      tenant_id=network.tenant_id)
         if subnet:
             return True
-        else:
-            self._delete_network(request, network)
-            return False
+
+        self._delete_network(request, network)
+        return False
