@@ -28,7 +28,10 @@ class VolumeGroups(horizon.Panel):
     name = _("Groups")
     slug = 'volume_groups'
     permissions = (
-        ('openstack.services.volume', 'openstack.services.volumev3'),
+        ('openstack.services.block-storage',
+         'openstack.services.block-store',
+         'openstack.services.volume',
+         'openstack.services.volumev3'),
     )
     policy_rules = (("volume", "group:get_all"),)
 
