@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import settings
 from django.http import HttpResponse
 from django.template import defaultfilters as filters
 from django.urls import NoReverseMatch
@@ -21,10 +20,10 @@ from django.utils import html
 from django.utils.http import urlencode
 from django.utils import safestring
 from django.utils.text import format_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from django.utils.translation import npgettext_lazy
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import messages
@@ -35,7 +34,13 @@ from openstack_dashboard.api import cinder
 from openstack_dashboard import policy
 from openstack_dashboard.usage import quotas
 
-DELETABLE_STATES = ("available", "error", "error_extending")
+DELETABLE_STATES = (
+    "available",
+    "error",
+    "error_extending",
+    "error_managing",
+    "error_restoring",
+)
 
 
 class VolumePolicyTargetMixin(policy.PolicyTargetMixin):
@@ -75,7 +80,7 @@ class LaunchVolumeNG(LaunchVolume):
 
     def __init__(self, attrs=None, **kwargs):
         kwargs['preempt'] = True
-        super(LaunchVolumeNG, self).__init__(attrs, **kwargs)
+        super().__init__(attrs, **kwargs)
 
     def get_link_url(self, datum):
         url = reverse(self.url)
@@ -97,17 +102,17 @@ class DeleteVolume(VolumePolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
-            u"Delete Volume",
-            u"Delete Volumes",
+        return ngettext_lazy(
+            "Delete Volume",
+            "Delete Volumes",
             count
         )
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
-            u"Scheduled deletion of Volume",
-            u"Scheduled deletion of Volumes",
+        return ngettext_lazy(
+            "Scheduled deletion of Volume",
+            "Scheduled deletion of Volumes",
             count
         )
 
@@ -140,7 +145,7 @@ class CreateVolume(tables.LinkAction):
 
     def __init__(self, attrs=None, **kwargs):
         kwargs['preempt'] = True
-        super(CreateVolume, self).__init__(attrs, **kwargs)
+        super().__init__(attrs, **kwargs)
 
     def allowed(self, request, volume=None):
         limits = api.cinder.tenant_absolute_limits(request)
@@ -152,7 +157,7 @@ class CreateVolume(tables.LinkAction):
 
         if gb_available <= 0 or volumes_available <= 0:
             if "disabled" not in self.classes:
-                self.classes = [c for c in self.classes] + ['disabled']
+                self.classes = list(self.classes) + ['disabled']
                 self.verbose_name = format_lazy(
                     '{verbose_name} {quota_exceeded}',
                     verbose_name=self.verbose_name,
@@ -220,14 +225,14 @@ class CreateSnapshot(VolumePolicyTargetMixin, tables.LinkAction):
         try:
             limits = api.cinder.tenant_absolute_limits(request)
         except Exception:
-            exceptions.handle(request, _('Unable to retrieve tenant limits.'))
+            exceptions.handle(request, _('Unable to retrieve project limits.'))
             limits = {}
 
         snapshots_available = (limits.get('maxTotalSnapshots', float("inf")) -
                                limits.get('totalSnapshotsUsed', 0))
 
         if snapshots_available <= 0 and "disabled" not in self.classes:
-            self.classes = [c for c in self.classes] + ['disabled']
+            self.classes = list(self.classes) + ['disabled']
             self.verbose_name = format_lazy(
                 '{verbose_name} {quota_exceeded}',
                 verbose_name=self.verbose_name,
@@ -237,7 +242,7 @@ class CreateSnapshot(VolumePolicyTargetMixin, tables.LinkAction):
 
 class CreateTransfer(VolumePolicyTargetMixin, tables.LinkAction):
     name = "create_transfer"
-    verbose_name = _("Create Transfer")
+    verbose_name = _("Create Volume Transfer")
     url = "horizon:project:volumes:create_transfer"
     classes = ("ajax-modal",)
     policy_rules = (("volume", "volume:create_transfer"),)
@@ -301,7 +306,7 @@ class RetypeVolume(VolumePolicyTargetMixin, tables.LinkAction):
 
 class AcceptTransfer(tables.LinkAction):
     name = "accept_transfer"
-    verbose_name = _("Accept Transfer")
+    verbose_name = _("Accept Volume Transfer")
     url = "horizon:project:volumes:accept_transfer"
     classes = ("ajax-modal",)
     icon = "exchange"
@@ -315,13 +320,13 @@ class AcceptTransfer(tables.LinkAction):
         volumes_available = usages['volumes']['available']
         if gb_available <= 0 or volumes_available <= 0:
             if "disabled" not in self.classes:
-                self.classes = [c for c in self.classes] + ['disabled']
+                self.classes = list(self.classes) + ['disabled']
                 self.verbose_name = format_lazy(
                     '{verbose_name} {quota_exceeded}',
                     verbose_name=self.verbose_name,
                     quota_exceeded=_("(Quota exceeded)"))
         else:
-            self.verbose_name = _("Accept Transfer")
+            self.verbose_name = _("Accept Volume Transfer")
             classes = [c for c in self.classes if c != "disabled"]
             self.classes = classes
         return True
@@ -337,7 +342,7 @@ class DeleteTransfer(VolumePolicyTargetMixin, tables.Action):
     # volume to the message, e.g. "Deleted volume transfer 'volume'". But
     # we are deleting the volume *transfer*, whose name is different.
     name = "delete_transfer"
-    verbose_name = _("Cancel Transfer")
+    verbose_name = _("Cancel Volume Transfer")
     policy_rules = (("volume", "volume:delete_transfer"),)
     help_text = _("This action cannot be undone.")
     action_type = "danger"
@@ -424,7 +429,8 @@ class AttachmentColumn(tables.WrappingColumn):
             vals = {"instance": instance,
                     "dev": html.escape(attachment.get("device", ""))}
             attachments.append(link % vals)
-        return safestring.mark_safe(", ".join(attachments))
+        if attachments:
+            return safestring.mark_safe(", ".join(attachments))
 
 
 class GroupNameColumn(tables.WrappingColumn):
@@ -445,10 +451,9 @@ def get_volume_type(volume):
 def get_encrypted_value(volume):
     if not hasattr(volume, 'encrypted') or volume.encrypted is None:
         return _("-")
-    elif volume.encrypted is False:
+    if volume.encrypted is False:
         return _("No")
-    else:
-        return _("Yes")
+    return _("Yes")
 
 
 def get_encrypted_link(volume):
@@ -462,41 +467,56 @@ class VolumesTableBase(tables.DataTable):
         ("in-use", True),
         ("available", True),
         ("creating", None),
+        ("downloading", None),
+        ("uploading", None),
+        ("retyping", None),
         ("error", False),
         ("error_extending", False),
+        ("error_managing", False),
+        ("error_restoring", False),
+        ("error_backing-up", False),
         ("maintenance", False),
     )
+    # https://opendev.org/openstack/cinder/src/branch/master/api-ref/source/v3/volumes-v3-volumes.inc
     STATUS_DISPLAY_CHOICES = (
         ("available", pgettext_lazy("Current status of a Volume",
-                                    u"Available")),
-        ("in-use", pgettext_lazy("Current status of a Volume", u"In-use")),
-        ("error", pgettext_lazy("Current status of a Volume", u"Error")),
+                                    "Available")),
+        ("in-use", pgettext_lazy("Current status of a Volume", "In-use")),
+        ("error", pgettext_lazy("Current status of a Volume", "Error")),
         ("creating", pgettext_lazy("Current status of a Volume",
-                                   u"Creating")),
+                                   "Creating")),
         ("error_extending", pgettext_lazy("Current status of a Volume",
-                                          u"Error Extending")),
+                                          "Error Extending")),
         ("extending", pgettext_lazy("Current status of a Volume",
-                                    u"Extending")),
+                                    "Extending")),
         ("attaching", pgettext_lazy("Current status of a Volume",
-                                    u"Attaching")),
+                                    "Attaching")),
         ("detaching", pgettext_lazy("Current status of a Volume",
-                                    u"Detaching")),
+                                    "Detaching")),
         ("deleting", pgettext_lazy("Current status of a Volume",
-                                   u"Deleting")),
+                                   "Deleting")),
         ("error_deleting", pgettext_lazy("Current status of a Volume",
-                                         u"Error deleting")),
+                                         "Error deleting")),
         ("backing-up", pgettext_lazy("Current status of a Volume",
-                                     u"Backing Up")),
+                                     "Backing Up")),
         ("restoring-backup", pgettext_lazy("Current status of a Volume",
-                                           u"Restoring Backup")),
+                                           "Restoring Backup")),
         ("error_restoring", pgettext_lazy("Current status of a Volume",
-                                          u"Error Restoring")),
+                                          "Error Restoring")),
         ("maintenance", pgettext_lazy("Current status of a Volume",
-                                      u"Maintenance")),
+                                      "Maintenance")),
         ("reserved", pgettext_lazy("Current status of a Volume",
-                                   u"Reserved")),
+                                   "Reserved")),
         ("awaiting-transfer", pgettext_lazy("Current status of a Volume",
-                                            u"Awaiting Transfer")),
+                                            "Awaiting Transfer")),
+        ("error_backing-up", pgettext_lazy("Current status of a Volume",
+                                           "Error Backing Up")),
+        ("downloading", pgettext_lazy("Current status of a Volume",
+                                      "Downloading")),
+        ("uploading", pgettext_lazy("Current status of a Volume",
+                                    "Uploading")),
+        ("retyping", pgettext_lazy("Current status of a Volume",
+                                   "Retyping")),
     )
     name = tables.Column("name",
                          verbose_name=_("Name"),
@@ -535,7 +555,7 @@ class UpdateMetadata(tables.LinkAction):
 
     def __init__(self, **kwargs):
         kwargs['preempt'] = True
-        super(UpdateMetadata, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def get_link_url(self, datum):
         obj_id = self.table.get_object_id(datum)
@@ -573,11 +593,7 @@ class VolumesTable(VolumesTableBase):
         table_actions = (CreateVolume, AcceptTransfer, DeleteVolume,
                          VolumesFilterAction)
 
-        launch_actions = ()
-        if settings.LAUNCH_INSTANCE_LEGACY_ENABLED:
-            launch_actions = (LaunchVolume,) + launch_actions
-        if settings.LAUNCH_INSTANCE_NG_ENABLED:
-            launch_actions = (LaunchVolumeNG,) + launch_actions
+        launch_actions = (LaunchVolumeNG,)
 
         row_actions = ((EditVolume, ExtendVolume,) +
                        launch_actions +
@@ -599,8 +615,8 @@ class DetachVolume(tables.BatchAction):
     def action_present(count):
         return npgettext_lazy(
             "Action to perform (the volume is currently attached)",
-            u"Detach Volume",
-            u"Detach Volumes",
+            "Detach Volume",
+            "Detach Volumes",
             count
         )
 
@@ -609,8 +625,8 @@ class DetachVolume(tables.BatchAction):
     def action_past(count):
         return npgettext_lazy(
             "Past action (the volume is currently being detached)",
-            u"Detaching Volume",
-            u"Detaching Volumes",
+            "Detaching Volume",
+            "Detaching Volumes",
             count
         )
 
