@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 PANEL_GROUP = 'object_store'
 PANEL_GROUP_NAME = _('Object Store')
