@@ -38,6 +38,8 @@
       getVersion: getVersion,
       getImage: getImage,
       createImage: createImage,
+      deactivateImage: deactivateImage,
+      reactivateImage: reactivateImage,
       updateImage: updateImage,
       deleteImage: deleteImage,
       getImageProps: getImageProps,
@@ -239,6 +241,20 @@
         });
     }
 
+    function deactivateImage(image) {
+      return apiService.post('/api/glance/images/' + image.id + '/actions/deactivate')
+        .catch(function onError() {
+          toastService.add('error', gettext('Unable to deactivate the image.'));
+        });
+    }
+
+    function reactivateImage(image) {
+      return apiService.post('/api/glance/images/' + image.id + '/actions/reactivate')
+        .catch(function onError() {
+          toastService.add('error', gettext('Unable to reactivate the image.'));
+        });
+    }
+
     /**
      * @name deleteImage
      * @description
