@@ -22,14 +22,16 @@ import logging
 import os
 import traceback
 from unittest import mock
+from urllib import parse
 
 from django.conf import settings
+from django.contrib.messages.storage import cookie as cookie_storage
 from django.contrib.messages.storage import default_storage
 from django.core.handlers import wsgi
 from django.test.client import RequestFactory
 from django.test import tag
+from django.test import testcases
 from django import urls
-from django.utils import http
 
 from openstack_auth import user
 from openstack_auth import utils
@@ -37,6 +39,7 @@ from requests.packages.urllib3.connection import HTTPConnection
 
 from horizon import base
 from horizon import conf
+from horizon import exceptions
 from horizon.test import helpers as horizon_helpers
 from openstack_dashboard import api
 from openstack_dashboard import context_processors
@@ -54,7 +57,7 @@ IsA = horizon_helpers.IsA
 IsHttpRequest = horizon_helpers.IsHttpRequest
 
 
-def create_mocks(target_methods):
+def create_mocks(target_methods, stop_mock=True):
     """decorator to simplify setting up multiple mocks at once
 
     :param target_methods: a dict to define methods to be patched using mock.
@@ -97,7 +100,6 @@ def create_mocks(target_methods):
             api.nova: [
                 'usage_get',
                 ('tenant_absolute_limits', 'nova_tenant_absolute_limits'),
-                'extension_supported',
             ],
             api.cinder: [
                 ('tenant_absolute_limits', 'cinder_tenant_absolute_limits'),
@@ -109,12 +111,15 @@ def create_mocks(target_methods):
             self.mock_nova_tenant_absolute_limits.return_value = ...
             self.mock_cinder_tenant_absolute_limits.return_value = ...
             ...
-            self.mock_extension_supported.assert_has_calls(....)
 
+    :param stop_mock: If True (default), mocks started in this decorator will
+        be stopped. Set this to False only if you cannot stop mocks when exiting
+        this decorator. The default value, True, should work for most cases.
     """
     def wrapper(function):
         @wraps(function)
         def wrapped(inst, *args, **kwargs):
+            patchers = []
             for target, methods in target_methods.items():
                 for method in methods:
                     if isinstance(method, str):
@@ -124,8 +129,13 @@ def create_mocks(target_methods):
                         method_mocked = method[0]
                         attr_name = method[1]
                     m = mock.patch.object(target, method_mocked)
+                    patchers.append(m)
                     setattr(inst, 'mock_%s' % attr_name, m.start())
-            return function(inst, *args, **kwargs)
+            retval = function(inst, *args, **kwargs)
+            if stop_mock:
+                for m in patchers:
+                    m.stop()
+            return retval
         return wrapped
     return wrapper
 
@@ -149,14 +159,14 @@ def _apply_panel_mocks(patchers=None):
 
 class RequestFactoryWithMessages(RequestFactory):
     def get(self, *args, **kwargs):
-        req = super(RequestFactoryWithMessages, self).get(*args, **kwargs)
+        req = super().get(*args, **kwargs)
         req.user = utils.get_user(req)
         req.session = []
         req._messages = default_storage(req)
         return req
 
     def post(self, *args, **kwargs):
-        req = super(RequestFactoryWithMessages, self).post(*args, **kwargs)
+        req = super().post(*args, **kwargs)
         req.user = utils.get_user(req)
         req.session = []
         req._messages = default_storage(req)
@@ -201,10 +211,10 @@ class TestCase(horizon_helpers.TestCase):
 
         self.patchers = _apply_panel_mocks()
 
-        super(TestCase, self).setUp()
+        super().setUp()
 
     def _setup_test_data(self):
-        super(TestCase, self)._setup_test_data()
+        super()._setup_test_data()
         test_utils.load_test_data(self)
         self.context = {
             'authorized_tenants': self.tenants.list(),
@@ -226,13 +236,15 @@ class TestCase(horizon_helpers.TestCase):
             'user_domain_name': self.domain.name,
             'tenant_id': self.tenant.id,
             'service_catalog': self.service_catalog,
-            'authorized_tenants': tenants
+            'authorized_tenants': tenants,
+            'roles': [{'id': '2', 'name': 'member'},
+                      {'id': '3', 'name': 'reader'}]
         }
         base_kwargs.update(kwargs)
         self.setActiveUser(**base_kwargs)
 
     def _setup_request(self):
-        super(TestCase, self)._setup_request()
+        super()._setup_request()
         self.request.session['token'] = self.token.id
 
     def tearDown(self):
@@ -240,7 +252,7 @@ class TestCase(horizon_helpers.TestCase):
         context_processors.openstack = self._real_context_processor
         utils.get_user = self._real_get_user
         mock.patch.stopall()
-        super(TestCase, self).tearDown()
+        super().tearDown()
 
         # cause a test failure if an unmocked API call was attempted
         if self.missing_mocks:
@@ -251,18 +263,22 @@ class TestCase(horizon_helpers.TestCase):
                       authorized_tenants=None, enabled=True, domain_id=None,
                       user_domain_name=None):
         def get_user(request):
-            return user.User(id=id,
-                             token=token,
-                             user=username,
-                             domain_id=domain_id,
-                             user_domain_name=user_domain_name,
-                             tenant_id=tenant_id,
-                             tenant_name=tenant_name,
-                             service_catalog=service_catalog,
-                             roles=roles,
-                             enabled=enabled,
-                             authorized_tenants=authorized_tenants,
-                             endpoint=settings.OPENSTACK_KEYSTONE_URL)
+            ret = user.User(
+                id=id,
+                token=token,
+                user=username,
+                domain_id=domain_id,
+                user_domain_name=user_domain_name,
+                tenant_id=tenant_id,
+                tenant_name=tenant_name,
+                service_catalog=service_catalog,
+                roles=roles,
+                enabled=enabled,
+                authorized_tenants=authorized_tenants,
+                endpoint=settings.OPENSTACK_KEYSTONE_URL,
+            )
+            ret._is_system_user = False
+            return ret
         utils.get_user = get_user
 
     def assertRedirectsNoFollow(self, response, expected_url):
@@ -271,9 +287,12 @@ class TestCase(horizon_helpers.TestCase):
         Asserts that the given response issued a 302 redirect without
         processing the view which is redirected to.
         """
-        loc = str(response._headers.get('location', None)[1])
-        loc = http.urlunquote(loc)
-        expected_url = http.urlunquote(expected_url)
+        if response.has_header('location'):
+            loc = response['location']
+        else:
+            loc = ''
+        loc = parse.unquote(loc)
+        expected_url = parse.unquote(expected_url)
         self.assertEqual(loc, expected_url)
         self.assertEqual(response.status_code, 302)
 
@@ -306,10 +325,14 @@ class TestCase(horizon_helpers.TestCase):
             assert len(errors) == count, \
                 "%d errors were found on the form, %d expected" % \
                 (len(errors), count)
-            if message and message not in str(errors):
-                self.fail("Expected message not found, instead found: %s"
-                          % ["%s: %s" % (key, [e for e in field_errors]) for
-                             (key, field_errors) in errors.items()])
+            if message:
+                text = testcases.assert_and_parse_html(
+                    self, message, None, '"message" contains invalid HTML:')
+                content = testcases.assert_and_parse_html(
+                    self, str(errors), None,
+                    '"_errors" in the response context is not valid HTML:')
+                match_count = content.count(text)
+                self.assertGreaterEqual(match_count, 1)
         else:
             assert len(errors) > 0, "No errors were found on the form"
 
@@ -368,7 +391,6 @@ class TestCase(horizon_helpers.TestCase):
     def mock_rest_request(**args):
         mock_args = {
             'user.is_authenticated': True,
-            'is_ajax.return_value': True,
             'policy.check.return_value': True,
             'body': ''
         }
@@ -423,6 +445,16 @@ class TestCase(horizon_helpers.TestCase):
                 len(errors), 0,
                 "No errors were found on the workflow")
 
+    def assertCookieMessage(self, response, expected_msg, detail_msg=None):
+        data = response.cookies["messages"]
+        storage = cookie_storage.CookieStorage(None)
+        messages = [m.message for m in storage._decode(data.value)]
+        if detail_msg is not None:
+            _expected = exceptions._append_detail(expected_msg, detail_msg)
+        else:
+            _expected = expected_msg
+        self.assertIn(_expected, messages)
+
 
 class BaseAdminViewTests(TestCase):
     """Sets an active user with the "admin" role.
@@ -432,7 +464,9 @@ class BaseAdminViewTests(TestCase):
     def setActiveUser(self, *args, **kwargs):
         if "roles" not in kwargs:
             kwargs['roles'] = [self.roles.admin._info]
-        super(BaseAdminViewTests, self).setActiveUser(*args, **kwargs)
+        else:
+            kwargs['roles'].append(self.roles.admin._info)
+        super().setActiveUser(*args, **kwargs)
 
     def setSessionValues(self, **kwargs):
         settings.SESSION_ENGINE = 'django.contrib.sessions.backends.file'
@@ -448,10 +482,16 @@ class BaseAdminViewTests(TestCase):
 
 class APITestCase(TestCase):
     def setUp(self):
-        super(APITestCase, self).setUp()
+        super().setUp()
         utils.patch_middleware_get_user()
 
 
+class RestAPITestCase(TestCase):
+    def setUp(self):
+        super().setUp()
+        mock.patch('horizon.utils.http.is_ajax', return_value=True).start()
+
+
 # APIMockTestCase was introduced to support mox to mock migration smoothly
 # but it turns we have still users of APITestCase.
 # We keep both for a while.
@@ -463,12 +503,12 @@ APIMockTestCase = APITestCase
 # Need this to test both Glance API V1 and V2 versions
 class ResetImageAPIVersionMixin(object):
     def setUp(self):
-        super(ResetImageAPIVersionMixin, self).setUp()
+        super().setUp()
         api.glance.VERSIONS.clear_active_cache()
 
     def tearDown(self):
         api.glance.VERSIONS.clear_active_cache()
-        super(ResetImageAPIVersionMixin, self).tearDown()
+        super().tearDown()
 
 
 @horizon_helpers.pytest_mark('selenium')
@@ -476,7 +516,7 @@ class ResetImageAPIVersionMixin(object):
 class SeleniumTestCase(horizon_helpers.SeleniumTestCase):
 
     def setUp(self):
-        super(SeleniumTestCase, self).setUp()
+        super().setUp()
 
         test_utils.load_test_data(self)
 
@@ -520,7 +560,9 @@ class SeleniumAdminTestCase(SeleniumTestCase):
     def setActiveUser(self, *args, **kwargs):
         if "roles" not in kwargs:
             kwargs['roles'] = [self.roles.admin._info]
-        super(SeleniumAdminTestCase, self).setActiveUser(*args, **kwargs)
+        else:
+            kwargs['roles'].append(self.roles.admin._info)
+        super().setActiveUser(*args, **kwargs)
 
 
 def my_custom_sort(flavor):
@@ -549,7 +591,7 @@ class PluginTestCase(TestCase):
     configuration.
     """
     def setUp(self):
-        super(PluginTestCase, self).setUp()
+        super().setUp()
         self.old_horizon_config = conf.HORIZON_CONFIG
         conf.HORIZON_CONFIG = conf.LazySettings()
         base.Horizon._urls()
@@ -562,7 +604,7 @@ class PluginTestCase(TestCase):
             self._discovered_panels[dash] = panels
 
     def tearDown(self):
-        super(PluginTestCase, self).tearDown()
+        super().tearDown()
         conf.HORIZON_CONFIG = self.old_horizon_config
         # Destroy our singleton and re-create it.
         base.HorizonSite._instance = None
