@@ -19,6 +19,9 @@ DashboardGroup = [
     cfg.StrOpt('dashboard_url',
                default='http://localhost/dashboard/',
                help='Where the dashboard can be found'),
+    cfg.StrOpt('auth_url',
+               default='http://localhost/identity/v3',
+               help='Where the keystone can be found'),
     cfg.StrOpt('help_url',
                default='https://docs.openstack.org/',
                help='Dashboard help page url'),
@@ -75,11 +78,11 @@ ImageGroup = [
                default='angular',
                help='type/version of images panel'),
     cfg.StrOpt('http_image',
-               default='http://download.cirros-cloud.net/0.3.1/'
-                       'cirros-0.3.1-x86_64-uec.tar.gz',
+               default='http://download.cirros-cloud.net/0.6.2/'
+                       'cirros-0.6.2-x86_64-uec.tar.gz',
                help='http accessible image'),
     cfg.ListOpt('images_list',
-                default=['cirros-0.3.5-x86_64-disk'],
+                default=['cirros-0.6.2-x86_64-disk'],
                 help='default list of images')
 ]
 
@@ -93,6 +96,9 @@ NetworkGroup = [
         # can be changed as per available external network.
         default='public',
         help='The external network for a router creation.'),
+    cfg.StrOpt('subnet_name',
+               default='public-subnet',
+               help='Default public network subnet name'),
 ]
 
 AvailableServiceGroup = [
@@ -102,9 +108,9 @@ AvailableServiceGroup = [
 ]
 
 SeleniumGroup = [
-    cfg.FloatOpt(
-        'message_implicit_wait',
-        default=0.1,
+    cfg.IntOpt(
+        'message_wait',
+        default=60,
         help='Timeout in seconds to wait for message confirmation modal'),
     cfg.IntOpt(
         'implicit_wait',
@@ -113,13 +119,13 @@ SeleniumGroup = [
               'It is used for every find_element, find_elements call.')),
     cfg.IntOpt(
         'explicit_wait',
-        default=90,
+        default=180,
         help=('Explicit timeout is used for long lasting operations, '
               'Methods using explicit timeout are usually prefixed with '
               '"wait"')),
     cfg.IntOpt(
         'page_timeout',
-        default=60,
+        default=120,
         help='Timeout in seconds to wait for a page to become available'),
     cfg.StrOpt(
         'screenshots_directory',
@@ -148,7 +154,7 @@ InstancesGroup = [
                default='nova',
                help='Availability zone to be selected for launch instances'),
     cfg.StrOpt('image_name',
-               default='cirros-0.5.2-x86_64-disk (15.5 MB)',
+               default='cirros-0.6.2-x86_64-disk (20.4 MB)',
                help='Boot Source to be selected for launch Instances'),
     cfg.StrOpt('flavor',
                default='m1.tiny',
@@ -186,6 +192,70 @@ PluginGroup = [
         help=('JSON string to define the page structure for the plugin')),
 ]
 
+ThemeGroup = [
+    cfg.StrOpt('project_name_xpath',
+               default='.//*[@class="context-project"]//ancestor::ul',
+               help='Default xpath for project name dropdown button'),
+    cfg.ListOpt('help_sequence',
+                default=['.//*[@class="dropdown user-menu"]',
+                         './/*[normalize-space()="Help"]'],
+                help='Default steps for redirect to help URL'),
+    cfg.BoolOpt('test_material_theme',
+                default=True,
+                help='Set to False to disallow running the material '
+                     'theme test'),
+    cfg.StrOpt('user_name_xpath',
+               default='.//*[@class="dropdown user-menu"]',
+               help='Default xpath for user name dropdown button'),
+    cfg.ListOpt('browse_left_panel_main',
+                default=['Project', 'Project', 'Project', 'Project',
+                         'Project', 'Project', 'Project', 'Project',
+                         'Project', 'Project', 'Project', 'Project',
+                         'Project', 'Project', 'Project', 'Project',
+                         'Admin', 'Admin', 'Admin', 'Admin', 'Admin',
+                         'Admin', 'Admin', 'Admin', 'Admin', 'Admin',
+                         'Admin', 'Admin', 'Admin', 'Admin', 'Admin',
+                         'Admin', 'Admin', 'Admin', 'Identity', 'Identity',
+                         'Identity', 'Identity', 'Identity'],
+                help='Main buttons for left browse panel'),
+    cfg.ListOpt('browse_left_panel_sec',
+                default=['None', 'Compute', 'Compute', 'Compute', 'Compute',
+                         'Compute', 'Volumes', 'Volumes', 'Network',
+                         'Network', 'Network', 'Network', 'Network',
+                         'Network', 'Network', 'Object store', 'None',
+                         'Compute', 'Compute', 'Compute', 'Compute', 'Compute',
+                         'Volume', 'Volume', 'Volume', 'Volume', 'Network',
+                         'Network', 'Network', 'Network', 'Network', 'Admin',
+                         'Admin', 'Admin', 'None', 'None', 'None', 'None',
+                         'None'],
+                help='Secondary buttons for left browse panel'),
+    cfg.StrOpt('b_l_p_sec_line_xpath',
+               default='.//*[@id="sidebar-accordion-{main_panel}"]',
+               help='Default xpath for first dropdown of browse panel'),
+    cfg.StrOpt('b_l_p_sec_line_req_btn',
+               default='.//a[@data-target='
+               '"#sidebar-accordion-{main_panel}-{sec_panel}"]',
+               help='Default xpath for button for open second dropdown of '
+               'left browse panel'),
+    cfg.StrOpt('b_l_p_sidebar_xpath',
+               default='.//*[@id="sidebar-accordion-{main_panel}-{sec_panel}"]',
+               help='Default xpath for second dropdown of browse panel'),
+]
+
+OIDCGroup = [
+    cfg.StrOpt('keycloak_test_user1_username',
+               default='kctestuser1',
+               help='Username to use for keycloak test user 1'),
+    cfg.StrOpt('keycloak_test_user1_password',
+               default='nomoresecrets1',
+               help='Password to use for keycloak test user 1.',
+               secret=True),
+    cfg.StrOpt('keycloak_test_user_home_project',
+               default='SSOproject',
+               help='Project to keep all objects belonging to a '
+               'regular keycloak user.'),
+]
+
 
 def _get_config_files():
     conf_dir = os.path.join(
@@ -213,6 +283,8 @@ def get_config():
     cfg.CONF.register_opts(InstancesGroup, group="launch_instances")
     cfg.CONF.register_opts(PluginGroup, group="plugin")
     cfg.CONF.register_opts(VolumeGroup, group="volume")
+    cfg.CONF.register_opts(ThemeGroup, group="theme")
+    cfg.CONF.register_opts(OIDCGroup, group="OIDC")
 
     return cfg.CONF
 
@@ -230,4 +302,6 @@ def list_opts():
         ("launch_instances", InstancesGroup),
         ("plugin", PluginGroup),
         ("volume", VolumeGroup),
+        ("theme", ThemeGroup),
+        ("OIDC", OIDCGroup),
     ]
