@@ -15,13 +15,22 @@
 import copy
 
 from openstack.network.v2 import agent as sdk_agent
+from openstack.network.v2 import extension
 from openstack.network.v2 import floating_ip as sdk_fip
 from openstack.network.v2 import network as sdk_net
 from openstack.network.v2 import network_ip_availability as \
     sdk_ip_availability
 from openstack.network.v2 import port as sdk_port
 from openstack.network.v2 import port_forwarding as sdk_pf
+from openstack.network.v2 import qos_bandwidth_limit_rule
+from openstack.network.v2 import qos_dscp_marking_rule
+from openstack.network.v2 import qos_minimum_bandwidth_rule
+from openstack.network.v2 import qos_minimum_packet_rate_rule
+from openstack.network.v2 import qos_policy
+
 from openstack.network.v2 import router as sdk_router
+from openstack.network.v2 import security_group as sdk_sec_group
+from openstack.network.v2 import security_group_rule as sdk_sec_group_rule
 from openstack.network.v2 import subnet as sdk_subnet
 from openstack.network.v2 import subnet_pool as sdk_subnet_pool
 from openstack.network.v2 import trunk as sdk_trunk
@@ -66,19 +75,10 @@ def data(TEST):
     TEST.neutron_availability_zones = utils.TestDataContainer()
 
     # Data return by neutronclient.
-    TEST.api_security_groups = utils.TestDataContainer()
-    TEST.api_security_group_rules = utils.TestDataContainer()
     TEST.api_pools = utils.TestDataContainer()
     TEST.api_vips = utils.TestDataContainer()
     TEST.api_members = utils.TestDataContainer()
     TEST.api_monitors = utils.TestDataContainer()
-    TEST.api_extensions = utils.TestDataContainer()
-    TEST.api_rbac_policies = utils.TestDataContainer()
-    TEST.api_qos_policies = utils.TestDataContainer()
-    TEST.api_dscp_mark_rule = utils.TestDataContainer()
-    TEST.api_bandwidth_limit_rule = utils.TestDataContainer()
-    TEST.api_minimum_bandwidth_rule = utils.TestDataContainer()
-    TEST.api_minimum_packet_rate_rule = utils.TestDataContainer()
 
     # Data returned by SDK:
     TEST.api_networks_sdk = list()
@@ -94,6 +94,14 @@ def data(TEST):
     TEST.api_ip_availability_sdk = list()
     TEST.api_port_forwardings_sdk = list()
     TEST.api_floating_ips_sdk = list()
+    TEST.api_security_groups_sdk = list()
+    TEST.api_security_group_rules_sdk = list()
+    TEST.api_qos_policies_sdk = list()
+    TEST.api_dscp_mark_rule_sdk = list()
+    TEST.api_bandwidth_limit_rule_sdk = list()
+    TEST.api_minimum_bandwidth_rule_sdk = list()
+    TEST.api_minimum_packet_rate_rule_sdk = list()
+    TEST.api_extensions_sdk = list()
 
     # 1st network.
     network_dict = {'is_admin_state_up': True,
@@ -799,12 +807,14 @@ def data(TEST):
                        'shared': False,
                        'description': 'SG without rules',
                        'id': 'f205f3bc-d402-4e40-b004-c62401e19b4b',
-                       'name': 'empty_group'}
+                       'name': 'empty_group',
+                       'security_group_rules': []}
     sec_group_shared = {'tenant_id': '1',
                         'shared': True,
                         'description': 'SG without rules',
                         'id': 'cca53e02-114e-4da3-917b-f19efa7cbc47',
-                        'name': 'shared_group'}
+                        'name': 'shared_group',
+                        'security_group_rules': []}
 
     def add_rule_to_group(secgroup, default_only=True):
         rule_egress_ipv4 = {
@@ -896,9 +906,11 @@ def data(TEST):
     sg_name_dict = dict([(sg['id'], sg['name']) for sg in groups])
     for sg in groups:
         # Neutron API.
-        TEST.api_security_groups.add(sg)
+        TEST.api_security_groups_sdk.append(
+            sdk_sec_group.SecurityGroup(**sg))
         for rule in sg.get('security_group_rules', []):
-            TEST.api_security_group_rules.add(copy.copy(rule))
+            TEST.api_security_group_rules_sdk.append(
+                sdk_sec_group_rule.SecurityGroupRule(**rule))
         # OpenStack Dashboard internaly API.
         TEST.security_groups.add(
             neutron.SecurityGroup(copy.deepcopy(sg), sg_name_dict))
@@ -909,12 +921,12 @@ def data(TEST):
     # Subnetpools
 
     # 1st subnetpool
-    subnetpool_dict = {'default_prefixlen': 24,
+    subnetpool_dict = {'default_prefix_length': 24,
                        'default_quota': None,
                        'id': '419eb314-e244-4088-aed7-851af9d9500d',
                        'ip_version': 4,
-                       'max_prefixlen': 32,
-                       'min_prefixlen': 12,
+                       'maximum_prefix_length': 32,
+                       'minimum_prefix_length': 12,
                        'name': 'mysubnetpool1',
                        'prefixes': ['172.16.0.0/12'],
                        'shared': False,
@@ -926,12 +938,12 @@ def data(TEST):
     TEST.subnetpools.add(subnetpool)
 
     # 2nd subnetpool (v6)
-    subnetpool_dict = {'default_prefixlen': 64,
+    subnetpool_dict = {'default_prefix_length': 64,
                        'default_quota': None,
                        'id': 'dcdad289-46f3-4298-bec6-41d91c942efa',
                        'ip_version': 6,
-                       'max_prefixlen': 64,
-                       'min_prefixlen': 60,
+                       'maximum_prefix_length': 64,
+                       'minimum_prefix_length': 60,
                        'name': 'mysubnetpool2',
                        'prefixes': ['2001:db8:42::/48'],
                        'shared': False,
@@ -994,13 +1006,13 @@ def data(TEST):
                    "alias": "security-groups-shared-filtering",
                    "description": "Support filtering security groups on "
                                   "the shared field"}
-    TEST.api_extensions.add(extension_1)
-    TEST.api_extensions.add(extension_2)
-    TEST.api_extensions.add(extension_3)
-    TEST.api_extensions.add(extension_4)
-    TEST.api_extensions.add(extension_5)
-    TEST.api_extensions.add(extension_6)
-    TEST.api_extensions.add(extension_7)
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_1))
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_2))
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_3))
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_4))
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_5))
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_6))
+    TEST.api_extensions_sdk.append(extension.Extension(**extension_7))
 
     # 1st agent.
     agent_dict = {"binary": "neutron-openvswitch-agent",
@@ -1096,12 +1108,12 @@ def data(TEST):
     policy_dict = {'id': 'a21dcd22-7189-cccc-aa32-22adafaf16a7',
                    'name': 'policy 1',
                    'tenant_id': '1'}
-    TEST.api_qos_policies.add(policy_dict)
+    TEST.api_qos_policies_sdk.append(qos_policy.QoSPolicy(**policy_dict))
     TEST.qos_policies.add(neutron.QoSPolicy(policy_dict))
     policy_dict1 = {'id': 'a21dcd22-7189-ssss-aa32-22adafaf16a7',
                     'name': 'policy 2',
                     'tenant_id': '1'}
-    TEST.api_qos_policies.add(policy_dict1)
+    TEST.api_qos_policies_sdk.append(qos_policy.QoSPolicy(**policy_dict1))
     TEST.qos_policies.add(neutron.QoSPolicy(policy_dict1))
 
     # qos rule - dscp mark
@@ -1109,7 +1121,8 @@ def data(TEST):
         "id": "5f126d84-551a-4dcf-bb01-0e9c0df0c794",
         "dscp_mark": 26
     }
-    TEST.api_dscp_mark_rule.add(dscp_mark_rule_dict)
+    TEST.api_dscp_mark_rule_sdk.append(
+        qos_dscp_marking_rule.QoSDSCPMarkingRule(**dscp_mark_rule_dict))
     TEST.dscp_mark_rule.add(neutron.DSCPMarkingRule(dscp_mark_rule_dict))
 
     # qos rule - bandwidth limit
@@ -1119,7 +1132,9 @@ def data(TEST):
         "max_burst_kbps": 0,
         "direction": "egress"
     }
-    TEST.api_bandwidth_limit_rule.add(bandwidth_limit_rule)
+    TEST.api_bandwidth_limit_rule_sdk.append(
+        qos_bandwidth_limit_rule.QoSBandwidthLimitRule(
+            **bandwidth_limit_rule))
     TEST.bandwidth_limit_rule.add(neutron.BandwidthLimitRule(
         bandwidth_limit_rule))
 
@@ -1129,7 +1144,9 @@ def data(TEST):
         "min_kbps": 10000,
         "direction": "egress"
     }
-    TEST.api_minimum_bandwidth_rule.add(minimum_bandwidth_rule)
+    TEST.api_minimum_bandwidth_rule_sdk.append(
+        qos_minimum_bandwidth_rule.QoSMinimumBandwidthRule(
+            **minimum_bandwidth_rule))
     TEST.minimum_bandwidth_rule.add(neutron.MinimumBandwidthRule(
         minimum_bandwidth_rule))
 
@@ -1139,7 +1156,9 @@ def data(TEST):
         "min_kpps": 10000,
         "direction": "egress"
     }
-    TEST.api_minimum_packet_rate_rule.add(minimum_packet_rate_rule)
+    TEST.api_minimum_packet_rate_rule_sdk.append(
+        qos_minimum_packet_rate_rule.QoSMinimumPacketRateRule(
+            **minimum_packet_rate_rule))
     TEST.minimum_packet_rate_rule.add(neutron.MinimumPacketRateRule(
         minimum_packet_rate_rule))
 
@@ -1151,7 +1170,6 @@ def data(TEST):
                         "target_tenant": "2",
                         "action": "access_as_external",
                         "tenant_id": "1"}
-    TEST.api_rbac_policies.add(rbac_policy_dict)
     TEST.rbac_policies.add(neutron.RBACPolicy(rbac_policy_dict))
     rbac_policy_dict1 = {"project_id": "1",
                          "object_type": "qos_policy",
@@ -1160,7 +1178,6 @@ def data(TEST):
                          "target_tenant": "2",
                          "action": "access_as_shared",
                          "tenant_id": "1"}
-    TEST.api_rbac_policies.add(rbac_policy_dict1)
     TEST.rbac_policies.add(neutron.RBACPolicy(rbac_policy_dict1))
 
     # TRUNKPORT
